==> resim_open_core-0.1.0-py3-none-manylinux2014_x86_64.whl: resim_python_client/api/experiences/update_experience.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response
from ... import errors

from ...models.update_experience_input import UpdateExperienceInput
from ...models.experience import Experience


def _get_kwargs(
    project_id: str,
    experience_id: str,
    *,
    body: UpdateExperienceInput,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "patch",
        "url": "/projects/{project_id}/experiences/{experience_id}".format(
            project_id=project_id,
            experience_id=experience_id,
        ),
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, Experience]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Experience.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = cast(Any, None)
        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, Experience]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,
) -> Response[Union[Any, Experience]]:
    """Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Experience]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        experience_id=experience_id,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,
) -> Optional[Union[Any, Experience]]:
    """Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, Experience]
    """

    return sync_detailed(
        project_id=project_id,
        experience_id=experience_id,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,
) -> Response[Union[Any, Experience]]:
    """Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Experience]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        experience_id=experience_id,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,
) -> Optional[Union[Any, Experience]]:
    """Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, Experience]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            experience_id=experience_id,
            client=client,
            body=body,
        )
    ).parsed

==> resim_open_core-0.3.0-py3-none-manylinux2014_x86_64.whl: resim_python_client/api/experiences/update_experience.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.update_experience_input import UpdateExperienceInput
from typing import cast
from typing import Dict
from ...models.experience import Experience



def _get_kwargs(
    project_id: str,
    experience_id: str,
    *,
    body: UpdateExperienceInput,

) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}


    

    

    _kwargs: Dict[str, Any] = {
        "method": "patch",
        "url": "/projects/{project_id}/experiences/{experience_id}".format(project_id=project_id,experience_id=experience_id,),
    }

    _body = body.to_dict()


    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[Any, Experience]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = Experience.from_dict(response.json())



        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = cast(Any, None)
        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[Any, Experience]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,

) -> Response[Union[Any, Experience]]:
    """  Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Experience]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
experience_id=experience_id,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,

) -> Optional[Union[Any, Experience]]:
    """  Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, Experience]
     """


    return sync_detailed(
        project_id=project_id,
experience_id=experience_id,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,

) -> Response[Union[Any, Experience]]:
    """  Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, Experience]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
experience_id=experience_id,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    project_id: str,
    experience_id: str,
    *,
    client: AuthenticatedClient,
    body: UpdateExperienceInput,

) -> Optional[Union[Any, Experience]]:
    """  Updates the experience.

    Args:
        project_id (str):
        experience_id (str):
        body (UpdateExperienceInput):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, Experience]
     """


    return (await asyncio_detailed(
        project_id=project_id,
experience_id=experience_id,
client=client,
body=body,

    )).parsed
